Sampler
==========

.. automodule:: stonesoup.sampler
    :no-members:

.. automodule:: stonesoup.sampler.base
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.sampler.particle
    :show-inheritance:

Detection
---------

.. automodule:: stonesoup.sampler.detection
    :show-inheritance:
